@@ -1,4 +1,4 @@
-# $Id: Config.pm,v 1.58 2006/03/31 20:05:49 joern Exp $
+# $Id: Config.pm,v 1.63 2006/07/02 13:04:35 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -10,7 +10,6 @@
 
 package Video::DVDRip::Config;
 use Locale::TextDomain qw (video.dvdrip);
-use Video::DVDRip::FixLocaleTextDomainUTF8;
 
 use base Video::DVDRip::Base;
 
@@ -192,14 +191,13 @@ my %CONFIG_PARAMETER = (
         value => "dvd::rip",
     },
     dvd_device => {
-        label => __ "DVD device",
+        label => __ "Default DVD device",
         type  => 'file',
         value => "/dev/dvd",
+        dvd_button => 1,
     },
-    writer_device => {
-        label => __ "Writer device file",
-        type  => 'file',
-        value => "/dev/cdrom",
+    selected_dvd_device => {
+        value   => "/dev/dvd",
     },
     eject_command => {
         label => __ "Eject Command",
@@ -299,103 +297,16 @@ my %CONFIG_PARAMETER = (
             . "calculates the video bitrate using this BPP value",
         rules => "positive-float",
     },
-    burn_cdrecord_device => {
-        label => __ "cdrecord device (n,n,n or filename)",
-        type  => 'string',
-        value => '0,X,0',
-    },
-    burn_writing_speed => {
-        label => __ "Writing speed",
-        type  => 'string',
-        value => '16',
-        presets => [ 1, 2, 4, 8, 12, 16, 20, 24, 30, 40 ],
-        rules   => "positive-integer",
-    },
-    burn_test_mode => {
-        label => __ "Simulate burning",
-        type  => 'switch',
-        value => 0,
-    },
-    burn_estimate_size => {
-        label   => __ "Estimate ISO size",
-        type    => 'switch',
+    default_subtitle_grab => {
+        label   => __ "Grab subtitles while ripping",
+        type    => "popup",
         value   => 0,
-        tooltip => __
-            "Estimate the size before start writing. Necessary for some TEAC drives for burning ISO discs on-the-fly",
-    },
-    burn_cdrecord_cmd => {
-        label   => __ "cdrecord command",
-        type    => 'string',
-        value   => '/usr/lib/xcdroast-0.98/bin/xcdrwrap CDRECORD',
         presets => [
-            '/usr/lib/xcdroast-0.98/bin/xcdrwrap CDRECORD', 'cdrecord',
-            'dvdrecord',
-        ],
-        rules => "executable-command",
-    },
-    burn_mkisofs_cmd => {
-        label   => __ "mkisofs command",
-        type    => 'string',
-        value   => 'mkisofs',
-        presets => ['mkisofs'],
-        rules   => "executable-command",
-    },
-    burn_vcdimager_cmd => {
-        label   => __ "vcdimager command",
-        type    => 'string',
-        value   => 'vcdimager',
-        presets => ['vcdimager'],
-        rules   => "executable-command",
-    },
-    burn_cdrdao_cmd => {
-        label   => __ "cdrdao command",
-        type    => 'string',
-        value   => 'cdrdao',
-        presets => ['cdrdao'],
-        rules   => "executable-command",
-    },
-    burn_cdrdao_driver => {
-        label   => __ "cdrdao driver",
-        type    => 'string',
-        value   => '',
-        presets => [
-            '',             'cdd2600',
-            'generic-mmc',  'generic-mmc-raw',
-            'plextor',      'plextor-scan',
-            'ricoh-mp6200', 'sony-cdu920',
-            'sony-cdu948',  'taiyo-yuden',
-            'teac-cdr55',   'toshiba',
-            'yamaha-cdr10x',
+            [ 'all'   => __"Grab all subtitles" ],
+            [ 'lang'  => __"Grab subtitles of preferred language" ],
+            [ 0       => __"Don't grab subtitles" ],
         ],
     },
-    burn_cdrdao_overburn => {
-        label => __ "Overburning",
-        type  => 'switch',
-        value => 1,
-    },
-    burn_cdrdao_eject => {
-        label => __ "Eject disc after write",
-        type  => 'switch',
-        value => 1,
-    },
-    burn_cdrdao_buffers => {
-        label => __ "Buffersize",
-        type  => 'string',
-        value => '',
-        rules => [ "positive-integer", "or-empty" ],
-    },
-    burn_blank_method => {
-        label   => __ "CD-RW blank method",
-        type    => 'popup',
-        value   => 'fast - minimally blank the entire disk',
-        presets => [
-            [ 'all - blank the entire disk', 'all - blank the entire disk' ],
-            [   'fast - minimally blank the entire disk',
-                'fast - minimally blank the entire disk'
-            ],
-        ],
-    },
-
     preferred_lang => {
         label   => __ "Preferred language",
         type    => 'popup',
@@ -405,13 +316,15 @@ my %CONFIG_PARAMETER = (
     workaround_nptl_bugs => {
         label => __ "Workaround transcode NPTL bugs",
         type  => 'switch',
-        value => 1,
+        value => (check_nptl_workaround_possible() ? 1 : 0),
+        avail_method => "check_nptl_workaround_possible",
     },
     nptl_ld_assume_kernel => {
         label   => __ "Set LD_ASSUME_KERNEL to",
         type    => "string",
         value   => "2.4.30",
         chained => 1,
+        avail_method => "check_nptl_workaround_possible",
     },
 );
 
@@ -429,21 +342,6 @@ my @CONFIG_ORDER = (
             play_stdin_command rar_command
             )
     ],
-    __ "CD burning" => [
-        qw(
-            writer_device        burn_cdrecord_device
-            burn_cdrecord_cmd    burn_cdrdao_cmd
-            burn_mkisofs_cmd     burn_vcdimager_cmd
-            burn_writing_speed   burn_estimate_size
-            burn_blank_method
-            )
-    ],
-    __ "cdrdao options" => [
-        qw(
-            burn_cdrdao_driver   burn_cdrdao_overburn
-            burn_cdrdao_eject    burn_cdrdao_buffers
-            )
-    ],
     __ "Cluster options" => [
         qw(
             cluster_master_local cluster_master_server
@@ -455,6 +353,7 @@ my @CONFIG_ORDER = (
             default_video_codec  default_container
             default_bpp
             preferred_lang
+            default_subtitle_grab
             workaround_nptl_bugs nptl_ld_assume_kernel
             )
     ],
@@ -732,6 +631,10 @@ sub new {
 sub init_nptl_bug_workaround {
     my $self = shift;
 
+    if ( !check_nptl_workaround_possible() ) {
+        $self->set_value("workaround_nptl_bugs", 0);
+    }
+
     if ( $self->get_value("workaround_nptl_bugs") ) {
         $ENV{LD_ASSUME_KERNEL} = $self->get_value('nptl_ld_assume_kernel');
     }
@@ -801,7 +704,7 @@ sub save {
     my $fh = FileHandle->new;
 
     open( $fh, "> $filename" ) or die "can't write $filename";
-    print $fh q{# $Id: Config.pm,v 1.58 2006/03/31 20:05:49 joern Exp $},
+    print $fh q{# $Id: Config.pm,v 1.63 2006/07/02 13:04:35 joern Exp $},
         "\n";
     print $fh
         "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
@@ -893,6 +796,37 @@ sub copy_values_from {
     1;
 }
 
+sub selected_dvd_device_list {
+    my $self = shift;
+
+    return unless $self->has("hal");
+    
+    #-- scan lshal output for DVD devices
+    my %devices;
+    open (my $fh, "LC_ALL=C lshal |") or die "can't fork lshal";
+    my $entry;
+    while ( <$fh> ) {
+        if ( /^udi/ ) {
+            $devices{$entry->{device}} = $entry->{model} if $entry && $entry->{dvd};
+            $entry = {};
+        }
+        if ( /storage\.model\s+=\s+'([^']+)/ ) {
+            $entry->{model} = $1;
+        }
+        if ( /block\.device\s+=\s+'([^']+)/ ) {
+            $entry->{device} = $1;
+        }
+        if ( /storage\.cdrom\.dvd\s+=\s+true/ ) {
+            $entry->{dvd} = 1;
+        }
+    }
+    close $fh;
+
+    $devices{$entry->{device}} = $entry->{model} if $entry && $entry->{dvd};    
+
+    return \%devices;
+}
+
 #---------------------------------------------------------------------
 # Test methods
 #---------------------------------------------------------------------
@@ -1027,4 +961,11 @@ sub _one_of_these {
     return __x( "'{value}' unknown: NOT Ok", value => $value );
 }
 
+sub check_nptl_workaround_possible {
+    my $check = qx[
+        LD_ASSUME_KERNEL=2.4.30 ls >/dev/null 2>&1 && echo NPTL_OK
+    ];
+    return $check =~ /NPTL_OK/;
+}
+
 1;
