@@ -1,4 +1,4 @@
-# $Id: FilterSettings.pm,v 1.11 2006/03/29 20:23:37 joern Exp $
+# $Id: FilterSettings.pm,v 1.13 2006/06/17 12:48:39 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -10,7 +10,6 @@
 
 package Video::DVDRip::FilterSettings;
 use Locale::TextDomain qw (video.dvdrip);
-use Video::DVDRip::FixLocaleTextDomainUTF8;
 
 use base Video::DVDRip::Base;
 use Video::DVDRip::FilterList;
@@ -24,7 +23,6 @@ sub new {
     my $class = shift;
 
     my $self = {
-
         # list of FilterSettingsInstance objects
         filters => [],
     };
@@ -135,8 +133,10 @@ sub check_filter_color_mode_ok {
         );
 
     return 1 if $filter->can_rgb and $filter->can_yuv;
+    return 1 if !$filter->can_video;
 
     foreach my $instance ( @{ $self->filters } ) {
+        next if !$instance->get_filter->can_video;
         if ( $filter->can_rgb ) {
             if ( not $instance->get_filter->can_rgb ) {
                 croak "msg:Filter is RGB only, but you "
@@ -177,9 +177,9 @@ sub del_filter {
     my ($id) = @par{'id'};
 
     my $index = $self->get_filter_instance_index( id => $id );
-    splice @{ $self->filters }, $index, 1;
+    my ($instance) = splice @{ $self->filters }, $index, 1;
 
-    1;
+    return $instance;
 }
 
 sub filter_used {
@@ -342,7 +342,6 @@ sub get_max_frames_needed {
 
 package Video::DVDRip::FilterSettingsInstance;
 use Locale::TextDomain qw (video.dvdrip);
-use Video::DVDRip::FixLocaleTextDomainUTF8;
 
 use Carp;
 
@@ -381,8 +380,8 @@ sub new {
     $self->set_queue('post')
         if $self->get_filter->is_pre_post
         and
-        not $self->get_filter->get_option( option_name => 'pre' )->fields->[0]
-        ->default;
+        not eval { $self->get_filter->get_option( option_name => 'pre' )->fields->[0]
+        ->default };
 
     return bless $self, $class;
 }
