@@ -1,4 +1,4 @@
-# $Id: Node.pm,v 1.19 2006/04/02 21:03:26 joern Exp $
+# $Id: Node.pm,v 1.21 2006/07/02 13:49:16 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -10,7 +10,6 @@
 
 package Video::DVDRip::GUI::Cluster::Node;
 use Locale::TextDomain qw (video.dvdrip);
-use Video::DVDRip::FixLocaleTextDomainUTF8;
 
 use base Video::DVDRip::GUI::Base;
 
@@ -206,6 +205,8 @@ sub build_node_form {
                     "If this node has the dvd::rip data hardrive locally "
                     . "connected, I/O intensive jobs are executed on this node "
                     . "with higher priority",
+                true_label => __"Yes",
+                false_label  => __"No",
             ),
             Gtk2::Ex::FormFactory::YesNo->new(
                 attr  => "cluster_node_edited.is_master",
@@ -213,6 +214,8 @@ sub build_node_form {
                 tip   => __ "Specify whether on this node runs the cluster "
                     . "control daemon. In that case no ssh remote command "
                     . "execution is neccessary",
+                true_label => __"Yes",
+                false_label  => __"No",
             ),
             Gtk2::Ex::FormFactory::Entry->new(
                 attr  => "cluster_node_edited.username",
