@@ -1,4 +1,4 @@
-# $Id: Context.pm,v 1.11 2006/04/10 19:48:03 joern Exp $
+# $Id: Context.pm,v 1.14 2006/07/02 13:05:10 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -13,10 +13,11 @@ package Video::DVDRip::GUI::Context;
 use base Video::DVDRip::GUI::Base;
 
 use Locale::TextDomain qw (video.dvdrip);
-use Video::DVDRip::FixLocaleTextDomainUTF8;
 use File::Basename;
+use Text::Wrap;
 
 use strict;
+use Carp;
 
 my @BITRATE_PARAMS = (
     "title.tc_container",                   "title.tc_video_codec",
@@ -200,16 +201,12 @@ sub create {
             vob_dir       => "project.name",
             avi_dir       => "project.name",
             snap_dir      => "project.name",
-            dvd_image_dir => "project.rip_mode",
         },
         attr_activity_href => {
             name          => $project_dirs_unlocked,
             vob_dir       => $project_dirs_unlocked,
             avi_dir       => $project_dirs_unlocked,
             snap_dir      => $project_dirs_unlocked,
-            dvd_image_dir => sub {
-                shift->rip_mode eq 'dvd_image';
-            },
         },
     );
 
@@ -817,6 +814,160 @@ sub create {
         },
     );
 
+    #-- Add FilterList object to Context
+    $context->add_object(
+        name   => "avail_filter_list",
+        object => Video::DVDRip::FilterList->get_filter_list,
+        attr_accessors_href => {
+            filters => sub {
+                my $filter_list = shift;
+                my $filter_settings = $context->get_object("filter_settings");
+                my @filters;
+                my $filters_href = $filter_list->filters;
+                foreach my $filter_name ( sort keys %{$filters_href} ) {
+                    push @filters, [
+                        $filter_name,
+                        $filters_href->{$filter_name}->desc,
+                        $filter_settings->filter_used( filter_name => $filter_name)
+                            && !$filters_href->{$filter_name}->can_multiple,
+                    ];
+                }
+                return \@filters;
+            },
+        },
+    );
+
+    #-- Filter Settings
+    $context->add_object (
+        name            => "filter_settings",
+        object          => undef,
+        aggregated_by   => "title.tc_filter_settings",
+        attr_accessors_href => {
+            filters => sub {
+                my $tc_filter_settings = shift;
+
+                my $selected_filters = $tc_filter_settings->get_selected_filters;
+
+                my @filters;
+	        foreach my $queue ( 'pre', 'post' ) {
+		    my $filter;
+                    push @filters, [
+                        $queue, "-----------", uc($queue)
+                    ];
+		    foreach my $filter_instance ( @{$selected_filters} ) {
+			eval { $filter = $filter_instance->get_filter };
+			next if $@;	# if a filter doesn't exist anymore
+			next if $filter_instance->queue ne $queue;
+                        push @filters, [
+			    $filter_instance->id,
+			    $filter->filter_name,
+			    $filter->desc,
+                        ],
+		    }
+	        }
+                
+                return \@filters;
+            },
+        },
+    );
+
+    #-- Add preview window to context
+    $context->add_object (
+        name   => "filter_window",
+        object => undef,
+        attr_depends_href => {
+            selected_avail_filter         => [ "selected_avail_filter_name"       ],
+            selected_used_filter_instance => [ "selected_used_filter_instance_id" ],
+
+            current_filter                => [ "selected_avail_filter_name",
+                                               "selected_used_filter_instance_id" ],
+#
+#            current_filter_settings       => [ "selected_avail_filter_name",
+#                                               "selected_used_filter_instance_id" ],
+        },
+        attr_accessors_href => {
+            set_selected_avail_filter_name => sub {
+                my $self = shift;
+                my ($value) = @_;
+                $self->set_selected_avail_filter_name($value);
+                my $filter = $self->selected_avail_filter;
+                $self->set_current_filter($filter);
+                my $instance = $filter ? $filter->get_dummy_instance : undef;
+                $self->set_current_filter_settings($instance);
+#                $self->build_filter_settings_form;
+                return $value;
+            },
+            set_selected_used_filter_instance_id => sub {
+                my $self = shift;
+                my ($value) = @_;
+                $self->set_selected_used_filter_instance_id($value);
+                my $instance = $self->selected_used_filter_instance;
+                $self->set_current_filter_settings($instance);
+#                $self->build_filter_settings_form;
+                my $filter = $instance ? $instance->get_filter : undef;
+                $self->set_current_filter($filter);
+                return $value;
+            },
+        },
+    );
+
+    #-- Add selected filter instance to context
+    $context->add_object (
+        name          => "current_filter",
+        object        => undef,
+        aggregated_by => "filter_window.current_filter",
+        attr_accessors_href => {
+            desc => sub {
+                my $self = shift;
+                local $Text::Wrap::columns = 32;
+                return wrap("","",$self->desc);
+            },
+            author => sub {
+                my $self = shift;
+                local $Text::Wrap::columns = 32;
+                return wrap("","",$self->author);
+            },
+        },
+    );
+
+    #-- Add selected filter to context
+    $context->add_object (
+        name          => "current_filter_settings",
+        object        => undef,
+#        aggregated_by => "filter_window.current_filter_settings",
+        accessor      => sub {
+            my $self = shift;
+            my ($attr, $value) = @_;
+            if ( @_ == 2 ) {
+                #-- setter
+                my $setter = "set_$attr";
+                return $self->$setter($value) if $self->can($setter);
+                #-- filter setting?
+                if ( $attr =~ /^filter_option_(.*)_(\d+)$/ ) {
+                    return $self->set_value(
+                        option_name => $1,
+                        idx         => $2,
+                        value       => $value
+                    );
+                }
+                croak "Unknown FilterSettingsInstance attribute: $attr";
+            }
+            else {
+                #-- getter
+                my $getter = $attr;
+                return $self->$getter() if $self->can($getter);
+                #-- filter setting?
+                if ( $attr =~ /^filter_option_(.*)_(\d+)$/ ) {
+                    return $self->get_value(
+                        option_name => $1,
+                        idx         => $2,
+                    );
+                }
+                croak "Unknown FilterSettingsInstance attribute: $attr";
+            }
+        },
+    );
+
     #-- Add cluster control daemon object to Context
     $context->add_object(
         name   => "cluster",
@@ -892,29 +1043,14 @@ sub create {
     #-- Add currently edited cluster title object to Context
     $context->add_object( name => "cluster_title_edited", );
 
-    #-- Add FilterList object to Context
-    $context->add_object(
-        name   => "filter_list",
-        object => Video::DVDRip::FilterList->get_filter_list,
+    #-- Add Preview Window to context
+    $context->add_object (
+        name => "preview_window",
         attr_accessors_href => {
-            filters => sub {
-                my $filter_list = shift;
-                my @filters;
-                my $filters_href = $filter_list->filters;
-                foreach my $filter_name ( sort keys %{$filters_href} ) {
-                    push @filters, [
-                        $filter_name,
-                        $filters_href->{$filter_name}->desc,
-                    ];
-                }
-                return \@filters;
-            },
+            set_paused => sub { 1 },
         },
     );
 
-    #-- Add Preview Window to context
-    $context->add_object ( name => "preview_window" );
-
     return $context;
 }
 
