@@ -1,4 +1,4 @@
-# $Id: Main.pm,v 1.82 2006/04/10 19:48:35 joern Exp $
+# $Id: Main.pm,v 1.86 2006/07/02 13:05:32 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -14,10 +14,9 @@ use strict;
 
 use base qw(Video::DVDRip::GUI::Base);
 use Locale::TextDomain qw (video.dvdrip);
-use Video::DVDRip::FixLocaleTextDomainUTF8;
 
 use Gtk2;
-use Gtk2::Ex::FormFactory 0.62;
+use Gtk2::Ex::FormFactory 0.65;
 use File::Basename;
 
 use Video::DVDRip::Project;
@@ -485,6 +484,8 @@ sub build_selected_title_factory {
         content => [
             Gtk2::Ex::FormFactory::Popup->new(
                 attr => "content.selected_title_nr",
+                tip => __"Choose a DVD title at any time here",
+
             ),
             Gtk2::Ex::FormFactory::Label->new(
                 attr => "title.get_title_info",
