@@ -1,4 +1,4 @@
-# $Id: Preferences.pm,v 1.5 2006/03/29 20:23:38 joern Exp $
+# $Id: Preferences.pm,v 1.9 2006/07/02 13:49:16 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -10,7 +10,6 @@
 
 package Video::DVDRip::GUI::Preferences;
 use Locale::TextDomain qw (video.dvdrip);
-use Video::DVDRip::FixLocaleTextDomainUTF8;
 
 use base qw(Video::DVDRip::GUI::Base);
 
@@ -65,9 +64,9 @@ sub build {
                 },
                 properties  => { modal => 1, },
                 closed_hook => sub     {
-                    $self->get_context->set_object( config => undef );
                     $config_ff->close if $config_ff;
                     $config_ff = undef;
+                    $self->get_context->set_object( config => undef );
                     1;
                 },
                 content => [
@@ -138,6 +137,13 @@ sub build_config_notebook {
             $ff_params{attr}               = "config.$item_name";
             $ff_params{changed_hook_after} = $changed_hook;
 
+            if ( $item_def->{avail_method} ) {
+                my $method = $item_def->{avail_method};
+                if ( ! Video::DVDRip::Config->$method() ) {
+                    $ff_params{active_cond} = sub { 0 };
+                }
+            }
+
             if ( $item_def->{type} eq 'string' ) {
                 if ( $item_def->{presets} ) {
                     $ff_class = "Gtk2::Ex::FormFactory::Combo";
@@ -158,6 +164,8 @@ sub build_config_notebook {
             }
             elsif ( $item_def->{type} eq 'switch' ) {
                 $ff_class = "Gtk2::Ex::FormFactory::YesNo";
+                $ff_params{true_label} = __"Yes";
+                $ff_params{false_label} = __"NO";
             }
             elsif ( $item_def->{type} eq 'popup' ) {
                 $ff_class = "Gtk2::Ex::FormFactory::Popup";
@@ -167,14 +175,42 @@ sub build_config_notebook {
                 warn
                     "Unknown config type '$item_def->{type}' for '$item_name'";
             }
-            push @items, $ff_class->new(%ff_params);
+
+            if ( $item_def->{dvd_button} && $self->has("hal") ) {
+                my $popup = Gtk2::Ex::FormFactory::Popup->new (
+                    attr     => "config.selected_dvd_device",
+                    expand_h => 0,
+                    changed_hook_after => sub {
+                        $self->get_context->set_object_attr (
+                            "config", "dvd_device",
+                            $self->get_context->get_object_attr (
+                                "config.selected_dvd_device",
+                            ),
+                        ),
+                    },
+                    tip => __"This is a list of connected DVD drives "
+                            ."found in your system"
+                );
+
+                $ff_params{expand} = 1;
+
+                push @items, Gtk2::Ex::FormFactory::HBox->new (
+                    label   => delete $ff_params{label},
+                    content => [
+                        $ff_class->new(%ff_params),
+                        $popup,
+                    ],
+                );
+            }
+            else {
+                push @items, $ff_class->new(%ff_params);
+            }
         }
 
-        push @notebook_pages,
-            Gtk2::Ex::FormFactory::Form->new(
+        push @notebook_pages, Gtk2::Ex::FormFactory::Form->new(
             title   => $label,
             content => \@items,
-            );
+        );
 
         ++$page_no;
     }
@@ -209,9 +245,9 @@ sub build_config_buttons {
                 label        => __ "Cancel",
                 stock        => "gtk-cancel",
                 clicked_hook => sub {
-                    $self->get_context->set_object( config => undef );
                     $config_ff->close;
                     $config_ff = undef;
+                    $self->get_context->set_object( config => undef );
                     1;
                 },
             ),
@@ -223,9 +259,9 @@ sub build_config_buttons {
                     $config_object->copy_values_from(
                         $self->get_context_object("config") );
                     $config_object->save;
-                    $self->get_context->set_object( config => undef );
                     $config_ff->close;
                     $config_ff = undef;
+                    $self->get_context->set_object( config => undef );
                     my $project = $self->get_context->get_object("project");
                     return if not $project;
                     $project->set_dvd_device(
