@@ -1,4 +1,4 @@
-# $Id: Subtitle.pm,v 1.9 2006/03/31 21:04:31 joern Exp $
+# $Id: Subtitle.pm,v 1.11 2006/06/17 12:54:08 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -13,7 +13,6 @@ package Video::DVDRip::GUI::Project::Subtitle;
 use base qw( Video::DVDRip::GUI::Base );
 
 use Locale::TextDomain qw (video.dvdrip);
-use Video::DVDRip::FixLocaleTextDomainUTF8;
 
 use Carp;
 use strict;
@@ -246,8 +245,9 @@ sub build_render_box {
                 attr  => "subtitle.tc_color_b",
                 width => 50,
                 rules => sub {
-                    $_[0] >= 0 && $_[0] <= 255
-                        || __ "Enter value between 0 and 255";
+                    $_[0] =~ /^\d+$/ && $_[0] >= 0 && $_[0] <= 255
+                        ? undef
+                        : __ "Value not between 0 and 255";
                 },
             ),
             Gtk2::Ex::FormFactory::Label->new(
