@@ -1,4 +1,4 @@
-# $Id: Title.pm,v 1.11 2006/03/31 21:04:31 joern Exp $
+# $Id: Title.pm,v 1.16 2006/07/02 13:07:38 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -13,7 +13,6 @@ package Video::DVDRip::GUI::Project::Title;
 use base qw( Video::DVDRip::GUI::Base );
 
 use Locale::TextDomain qw (video.dvdrip);
-use Video::DVDRip::FixLocaleTextDomainUTF8;
 
 use Carp;
 use strict;
@@ -64,11 +63,19 @@ sub build_factory {
                         object => "project",
                         label  => __ "Open DVD tray",
                         tip    => __
-                            "Open the tray of your configuried DVD device",
+                            "Open the tray of your configured DVD device",
                         stock        => "gtk-open",
                         clicked_hook => sub { $self->eject_dvd },
-                        active_cond    => sub { !$self->progress_is_active },
-                        active_depends => "progress.is_active",
+                        active_cond    => sub {
+                               $self->selected_title
+                            && !-d $self->selected_title->project->dvd_device
+                            && !$self->progress_is_active
+                        },
+                        active_depends => [
+                            "title",
+                            "project.dvd_device",
+                            "progress.is_active",
+                        ],
                     ),
                     Gtk2::Ex::FormFactory::Button->new(
                         object => "project",
@@ -77,8 +84,16 @@ sub build_factory {
                             "Close the tray of your configuried DVD device",
                         stock        => "gtk-close",
                         clicked_hook => sub { $self->insert_dvd },
-                        active_cond    => sub { !$self->progress_is_active },
-                        active_depends => "progress.is_active",
+                        active_cond    => sub {
+                               $self->selected_title
+                            && !-d $self->selected_title->project->dvd_device
+                            && !$self->progress_is_active
+                        },
+                        active_depends => [
+                            "title",
+                            "project.dvd_device",
+                            "progress.is_active",
+                        ],
                     ),
                 ]
             ),
@@ -194,7 +209,8 @@ sub build_audio_viewing_chapter_factory {
                         label => __ "No",
                         tip   => __
                             "No subitle images are created while ripping "
-                            . "but can be grabbed later on demand",
+                            . "but can be grabbed later on demand. This is "
+                            . "the fastest ripping mode.",
                     ),
                     Gtk2::Ex::FormFactory::RadioButton->new(
                         attr  => "title.tc_rip_subtitle_mode",
@@ -202,15 +218,18 @@ sub build_audio_viewing_chapter_factory {
                         label => __ "All",
                         tip   => __
                             "Images of all subtitle streams are created "
-                            . "while ripping and available for preview "
-                            . "immediately",
+                            . "during ripping and available for preview "
+                            . "immediately. Note that this will slow down "
+                            . "the ripping process significantly.",
                     ),
                     Gtk2::Ex::FormFactory::RadioButton->new(
                         attr  => "title.tc_rip_subtitle_mode",
                         value => "lang",
                         label => __ "By language",
                         tip   => __
-                            "Grab subtitle images of specific languages only",
+                            "Grab subtitle images of specific languages only. "
+                            . "Note that this will slow down the ripping process "
+                            . "significantly.",
                     ),
                 ],
 
@@ -237,7 +256,7 @@ sub build_audio_viewing_chapter_factory {
                     Gtk2::Ex::FormFactory::RadioButton->new(
                         attr  => "title.tc_use_chapter_mode",
                         value => "0",
-                        label => __ "No",
+                        label => __ "None",
                         tip   => __ "The title is handled as a whole "
                             . "ignoring all chapter marks",
                     ),
@@ -407,8 +426,11 @@ sub view_title {
 sub eject_dvd {
     my $self = shift;
 
+    my $title = $self->selected_title;
+
     my $command
-        = $self->config('eject_command') . " " . $self->config('dvd_device');
+        = $self->config('eject_command') . " " .
+            $title->project->dvd_device;
 
     system("$command &");
 
@@ -418,8 +440,10 @@ sub eject_dvd {
 sub insert_dvd {
     my $self = shift;
 
+    my $title = $self->selected_title;
+
     my $command = $self->config('eject_command') . " -t "
-        . $self->config('dvd_device');
+        . $title->project->dvd_device;
 
     system("$command &");
 
