@@ -1,4 +1,4 @@
-# $Id: Transcode.pm,v 1.15 2006/04/10 19:50:53 joern Exp $
+# $Id: Transcode.pm,v 1.18 2006/07/02 13:49:16 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -13,7 +13,6 @@ package Video::DVDRip::GUI::Project::Transcode;
 use base qw( Video::DVDRip::GUI::Base );
 
 use Locale::TextDomain qw (video.dvdrip);
-use Video::DVDRip::FixLocaleTextDomainUTF8;
 
 use Carp;
 use strict;
@@ -193,7 +192,9 @@ sub build_video_factory {
                     . "video bitrate accuracy significantly. But the "
                     . "whole transcoding needs nearly twice the time. "
                     . "It's strongly recommended to use 2-pass encoding "
-                    . "whenever possible."
+                    . "whenever possible.",
+                true_label => __"Yes",
+                false_label  => __"No",
             ),
             Gtk2::Ex::FormFactory::CheckButton->new(
                 label => __ "Reuse log",
@@ -227,9 +228,8 @@ sub build_video_factory {
                 label => __ "Configure filters & preview...",
                 tip   => __ "This opens a dialog which gives you access "
                     . "all filters transcode supports.",
-                active       => 0,
+#                active       => 0,
                 clicked_hook => sub {
-                    return 1;
                     $self->open_filters_window;
                 },
             ),
@@ -610,10 +610,14 @@ sub build_general_options_factory {
             Gtk2::Ex::FormFactory::YesNo->new(
                 attr  => "title.tc_preview",
                 label => __ "Preview window",
+                true_label => __"Yes",
+                false_label  => __"No",
             ),
             Gtk2::Ex::FormFactory::YesNo->new(
                 attr  => "title.tc_psu_core",
                 label => __ "Use PSU core",
+                true_label => __"Yes",
+                false_label  => __"No",
             ),
             Gtk2::Ex::FormFactory::HBox->new(
                 label   => __ "Execute afterwards",
