@@ -1,4 +1,4 @@
-# $Id: JobPlanner.pm,v 1.7 2006/04/23 14:25:14 joern Exp $
+# $Id: JobPlanner.pm,v 1.10 2006/07/02 08:33:23 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -16,9 +16,8 @@ use Carp;
 use strict;
 
 use Locale::TextDomain qw (video.dvdrip);
-use Event::ExecFlow qw (video.dvdrip);
+use Event::ExecFlow 0.62 qw (video.dvdrip);
 
-use Video::DVDRip::FixLocaleTextDomainUTF8;
 
 sub get_project                 { shift->{project}                      }
 sub set_project                 { shift->{project}              = $_[1] }
@@ -956,7 +955,17 @@ sub build_transcode_video_pass_job {
 	$bc->calculate;
         $diskspace_consumed = int(($bc->video_size + $bc->non_video_size)*1024);
     }
-    
+
+    if ( $pass == 1 &&
+         $title->has_vbr_audio && $title->tc_multipass ) {
+	my $bc = Video::DVDRip::BitrateCalc->new (
+		title		=> $title,
+		with_sheet	=> 0,
+	);
+	$bc->calculate;
+        $diskspace_consumed += $bc->audio_size * 1024;
+    }
+                 
     my $progress_parser = $self->get_transcode_progress_parser($title);
     
     my $post_callbacks;
@@ -1031,7 +1040,7 @@ sub build_merge_audio_job {
 
     my $progress_max = $title->get_transcode_progress_max;
 
-    my $diskspace_consumed;
+    my ($diskspace_consumed, $diskspace_freed);
     my $bc = Video::DVDRip::BitrateCalc->new (
 	    title       => $title,
 	    with_sheet	=> 0,
@@ -1041,7 +1050,8 @@ sub build_merge_audio_job {
     my $runtime = $title->runtime;
     my $audio_size = int($runtime * $bitrate / 8);
     $diskspace_consumed = $audio_size + $bc->video_size * 1024;
-    
+    $diskspace_freed    = $audio_size;
+
     my $command = sub {
         $title->get_merge_audio_command (
 	    vob_nr        => $vob_nr,
@@ -1064,6 +1074,7 @@ sub build_merge_audio_job {
         title               => $info,
         command             => $command,
         diskspace_consumed  => $diskspace_consumed,
+        diskspace_freed     => $diskspace_freed,
         progress_ips        => __"fps",
         progress_max        => $progress_max,
         progress_parser     => $progress_parser,
@@ -1643,8 +1654,8 @@ sub build_create_wav_job {
         my $sample_rate = $title->audio_track->sample_rate;
         my $runtime = $title->runtime;
         my $diskspace_consumed = int($runtime * $sample_rate * 2 / 1024);
-#        $diskspace_consumed = int($diskspace_consumed / $title->chapters)
-#            if $chapter;
+        $diskspace_consumed = int($diskspace_consumed / $title->chapters)
+            if $chapter;
 
         my $command = $title->get_create_wav_command;
 
