@@ -1,4 +1,4 @@
-# $Id: Project.pm,v 1.52 2006/03/31 20:31:54 joern Exp $
+# $Id: Project.pm,v 1.56 2006/07/02 13:48:36 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -10,7 +10,6 @@
 
 package Video::DVDRip::Project;
 use Locale::TextDomain qw (video.dvdrip);
-use Video::DVDRip::FixLocaleTextDomainUTF8;
 
 use base Video::DVDRip::Base;
 
@@ -35,11 +34,11 @@ sub snap_dir			{ shift->{snap_dir}  			}
 sub content			{ shift->{content}			}
 sub selected_title_nr		{ shift->{selected_title_nr}		}
 sub rip_mode			{ shift->{rip_mode} 	       || 'rip'	}
-sub dvd_image_dir		{ shift->{dvd_image_dir}		}
 sub convert_message		{ shift->{convert_message}		}
 sub last_selected_nb_page	{ shift->{last_selected_nb_page}	}
 sub created			{ my $created = shift->{created};
 				  !defined($created) ? 1 : $created	}
+sub selected_dvd_device         { shift->{selected_dvd_device}          }
 
 sub set_version			{ shift->{version}		= $_[1] }
 sub set_filename		{ shift->{filename}		= $_[1] }
@@ -50,10 +49,10 @@ sub set_snap_dir		{ shift->{snap_dir}		= $_[1]	}
 sub set_content			{ shift->{content}		= $_[1] }
 sub set_selected_title_nr	{ shift->{selected_title_nr}	= $_[1] }
 sub set_rip_mode		{ shift->{rip_mode}		= $_[1]	}
-sub set_dvd_image_dir		{ shift->{dvd_image_dir}	= $_[1]	}
 sub set_convert_message		{ shift->{convert_message}	= $_[1]	}
 sub set_last_selected_nb_page	{ shift->{last_selected_nb_page}= $_[1]	}
 sub set_created			{ shift->{created}		= $_[1]	}
+sub set_selected_dvd_device     { shift->{selected_dvd_device}  = $_[1] }
 
 sub logfile {
     my $self = shift;
@@ -100,6 +99,7 @@ sub new {
         name              => "unnamed",
         filename          => "",
         dvd_device        => $class->config('dvd_device'),
+        selected_dvd_device => $class->config('dvd_device'),
         rip_mode          => "rip",
         vob_dir           => "$base_project_dir/unnamed/vob",
         avi_dir           => "$base_project_dir/unnamed/avi",
@@ -151,7 +151,7 @@ sub save {
     my $fh = FileHandle->new;
 
     open( $fh, "> $filename" ) or confess "can't write $filename";
-    print $fh q{# $Id: Project.pm,v 1.52 2006/03/31 20:31:54 joern Exp $},
+    print $fh q{# $Id: Project.pm,v 1.56 2006/07/02 13:48:36 joern Exp $},
         "\n";
     print $fh
         "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
@@ -314,21 +314,7 @@ sub get_free_diskspace {
 
 sub rip_data_source {
     my $self = shift;
-
-    my $mode = $self->rip_mode;
-
-    my $source;
-
-    if ( $mode eq 'rip' or $mode eq 'dvd' ) {
-        $source = $self->dvd_device;
-
-    }
-    elsif ( $mode eq 'dvd_image' ) {
-        $source = $self->dvd_image_dir;
-
-    }
-
-    return $source;
+    return $self->dvd_device;
 }
 
 sub resolve_symlinks {
@@ -379,7 +365,7 @@ sub get_mount_dir_from_mtab {
 sub dvd_mount_point {
     my $self = shift;
 
-    my $dvd_device = $self->config('dvd_device');
+    my $dvd_device = $self->dvd_device;
 
     my $dvd_mount_point
         = $self->get_mount_dir_from_mtab( $dvd_device,  "/etc/mtab" )
@@ -391,20 +377,7 @@ sub dvd_mount_point {
 sub dvd_mount_dir {
     my $self = shift;
 
-    my $mode = $self->rip_mode;
-
-    my $dir;
-
-    if ( $mode eq 'rip' or $mode eq 'dvd' ) {
-        $dir = $self->dvd_mount_point;
-
-    }
-    elsif ( $mode eq 'dvd_image' ) {
-        $dir = $self->dvd_image_dir;
-
-    }
-
-    return $dir;
+    return $self->dvd_mount_point;
 }
 
 sub copy_ifo_files {
@@ -439,11 +412,15 @@ sub copy_ifo_files {
     1;
 }
 
+sub selected_dvd_device_list {
+    my $self = shift;
+    
+    return $self->config_object->selected_dvd_device_list;
+}
+
 sub dvd_is_mounted {
     my $self = shift;
 
-    return 1 if $self->rip_mode eq 'dvd_image';
-
     my $dvd_mount_point = $self->dvd_mount_point;
 
     return 1 if -d "$dvd_mount_point/video_ts";
@@ -454,7 +431,7 @@ sub dvd_is_mounted {
 sub mount_dvd {
     my $self = shift;
 
-    return 1 if $self->rip_mode eq 'dvd_image';
+    return 1 if -d $self->dvd_device;
 
     my $dvd_mount_point = $self->dvd_mount_point;
 
@@ -482,7 +459,7 @@ sub mount_dvd {
 sub umount_dvd {
     my $self = shift;
 
-    return 1 if $self->rip_mode eq 'dvd_image';
+    return 1 if -d $self->dvd_device;
 
     my $dvd_mount_point = $self->dvd_mount_point;
 
@@ -550,13 +527,14 @@ sub check_for_deleted_filters {
         my $i = 0;
         foreach my $filter_instance ( @{$selected_filters} ) {
             eval { $filter_instance->get_filter };
-            if ($@) {
-                print(    __"Warning: filter '"
-                        . $filter_instance->filter_name
-                        . __ "' removed from title #"
-                        . $title->nr
-                        . __ " because this transcode installation "
-                        . "does not provide it anymore.\n" );
+            if ( $@ ) {
+                print __x(
+                     "Warning: filter {filter} removed from title #{nr}"
+                    ." because this transcode installation doesn't"
+                    ." provide it anymore",
+                    filter => $filter_instance->filter_name,
+                    nr     => $title->nr,
+                ),"\n";
                 push @remove_filters, $i;
             }
             ++$i;
